<img src="https://raw.githubusercontent.com/equinor/pysand/master/resources/logo.png" align="center" title="pySand"/>

PySand is a python package with sand management related calculations for oil and gas industry developed by Equinor.
* Acoustic sand detectors standard calibration and quantification
* Basic (black oil) fluid properties
* DNVGL RP-O501 erosion rate calculations 
* ER probe sand quantification

### Installation instructions
```
pip install pysand
```
###### Upgrade

```
pip install pysand --upgrade
```
###### Removal

```
pip uninstall pysand
```

### Usage
Jupyter Notebooks with example usage can be found in the example directory:
* [Acoustic sand detector](examples/asd.ipynb)
* [Erosion](examples/erosion.ipynb)
* [Fluid properties](examples/fluidproperties.ipynb)

Bringing them all together:
* [All pySand modules](examples/all_modules.ipynb)
